@@ -478,9 +478,6 @@ class SagemakerFeatureStore:
                 record = [
                     {"FeatureName": column, "ValueAsString": str(row[column])}
                     for column in row.__fields__
-                    if row[column] is not None
-                    and row[column] != ""
-                    and row[column] != 0.0
                 ]
                 resp = runtime.put_record(
                     FeatureGroupName=feature_group_name, Record=record
@@ -808,7 +805,42 @@ if __name__ == "__main__":
     # print(training_df.iloc[0])
 
     # List Feature Groups
-    print(feature_store.get_feature_groups_list())
+    # print(feature_store.get_feature_groups_list())
+
+    # feature_store.describe_feature_group("customers-feature-group-16-07-38-24")
+
+    # ids = [
+    #     "7ACqWePjj93Ra58C#%AFkjZBgb2QwSvkBg",
+    #     "4xZvURxboGpvZ4wR#%bPXUwoonqbcCwZzt",
+    #     "3wYf9qRdbqNZBuaB#%HCXPasj9kdaerfJp",
+    #     "Dx36hH8tJRiC2tXF#%f2dWqBDjvuD8aRZr",
+    #     "983a8vaDFVKfCasC#%AgMNybV8r84nBako",
+    #     "KKoTupfC4DTGJg8w#%yFAtoBruGhuWEm7C",
+    #     "N6RE7aTGYDeu2dY3#%YJYFNdDaTS6E6Bv8",
+    #     "FrSrzwkrSFG6AEB4#%afy6pRmxFPUC2QfB",
+    #     "DDHhR8XH9GNHbsKG#%y2j5JYJKw2qSLTrw",
+    #     "Gf8f6YhPqP8kssRC#%t558GGU36JyjQdvg",
+    #     "85DJkCmcP7L774Vj#%WELyLihSX7hwYaCC",
+    #     "BbDf4QxWTAgTrKem#%xkrbQ2Yxy7j1QYgE",
+    #     "6vj8kTKNbeBNG9vs#%WimSbjUCdQZcg6QV",
+    #     "92QSm6ww9e3RQNmb#%D7FDrREg7pQm7EeV",
+    #     "K1tgc3iGokbQeGCW#%RHXWe8ZPuKYrrkaU",
+    #     "MWHALy1FjwYJAMos#%k4bcYoXmLFcFMEUj",
+    #     "5WAeKo7VwuPEVCsq#%DksJZ7H45SkgNcgP",
+    #     "53UhdvnWmXLaExcp#%t85tsDXFzdJRs3z7",
+    #     "F7m5Fw4C8t6PFZn7#%txxxiqeXAWhep8v5",
+    #     "G9EpTSLLDHwhZKiF#%va4emKDC2Fxa6YoP",
+    # ]
+
+    # data = feature_store.runtime.batch_get_record(
+    #     Identifiers=[
+    #         {
+    #             "FeatureGroupName": "v3-cross-2021-12-06",
+    #             "RecordIdentifiersValueAsString": ids,
+    #         },
+    #     ]
+    # )
+    # print(json.dumps(data, indent=2))
 
     # Describe feature group
     # feature_store.describe_feature_group("v3-cross-test")
